'use strict';

var _gcodeUtilsDocument = require('gcode-utils-document');

var _gcodeUtilsDocument2 = _interopRequireDefault(_gcodeUtilsDocument);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function GCodeDriver(stream) {
  var doc = new _gcodeUtilsDocument2.default();
  this.stream = stream || {
    write: function write(str) {
      doc.append(str);
    }
  };
  this.getDoc = function () {
    return doc;
  };
}

GCodeDriver.prototype = {
  send: function send(code, params) {
    var command = code;

    if (!command) return;

    if (params) {
      'xyzabcijkf'.split('').forEach(function (k) {
        if (params[k] === undefined || params[k] === null) return;

        command += ' ' + k.toUpperCase() + params[k];
      });
    }

    this.stream.write(command);
  },
  init: function init() {
    // this.send('G90'); // Absolute mode
  },
  unit: function unit(name) {
    name = name.toLowerCase();
    this.send({ 'inch': 'G20', 'mm': 'G21' }[name]);
  },
  speed: function speed(n) {
    this.send('S' + n);
  },
  feed: function feed(n) {
    this.send('F' + n);
  },
  coolant: function coolant(type) {
    if (type === 'mist') {
      // special
      this.send('M07');
    } else if (type) {
      // flood
      this.send('M08');
    } else {
      // off
      this.send('M09');
    }
  },
  zero: function zero(params) {
    this.send('G28.3', params);
  },
  atc: function atc(id) {
    this.send('M6', { T: id });
  },
  rapid: function rapid(params) {
    this.send('G0', params);
  },
  linear: function linear(params) {
    this.send('M3');
    this.send('G1', params);
    this.send('M5');
  },
  arcCW: function arcCW(params) {
    this.send('M3');
    this.send('G2', params);
    this.send('M5');
  },
  arcCCW: function arcCCW(params) {
    this.send('M3');
    this.send('G3', params);
    this.send('M5');
  },
  meta: function meta(params) {
    var comment = '(';
    for (var k in params) {
      comment += k + '=' + params[k];
    }
    comment += ')';

    this.send(comment);
  }
};

module.exports = GCodeDriver;