'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = convert;

var _gcodeUtilsDocument = require('gcode-utils-document');

var _gcodeUtilsDocument2 = _interopRequireDefault(_gcodeUtilsDocument);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var paper = require('paper');
var canvas = new paper.Canvas(26, 26);
paper.setup(canvas);

function preamble(input, options) {
  var feedRate = options.feed || 3000;
  return 'G21 G90\nG1 F' + feedRate + '\n';
}

function postamble(input, options) {
  return ';end';
}

// Not compatible with alpha, move to binary color scheme
function getIntensity(raster, x, y) {
  var color = raster.getPixel(x, y);
  var on = color.gray > 0.1 ? 0 : 1;
  return on;
}

function convertRaster(raster, options) {
  var direction = 1;
  var height = raster.height;
  var width = raster.width;
  var doc = new _gcodeUtilsDocument2.default();
  doc.setRelativePositioning();

  for (var y = 0; y < height; y++) {
    for (var x = 0; x < width; x++) {
      var intensity = getIntensity(raster, x, y);
      var xOffset = direction * options.toolDiameter;
      if (intensity > 0) {
        doc.spindleOn(intensity);
        doc.linearX(xOffset);
        doc.spindleOff();
      } else {
        doc.linearX(xOffset);
      }
    }

    //Reverse direction after each row
    direction = -direction;

    //Go to next row
    doc.linearY(-options.toolDiameter);
  }
  return doc;
}

function convert(input) {
  var options = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
  var callback = arguments[2];

  options.toolDiameter = options.toolDiameter || 0.15;
  var raster = new paper.Raster(input);
  raster.onLoad = function () {
    var doc = convertRaster(raster, options);

    doc.prepend(preamble(input, options)).append(postamble(input, options));

    console.log(doc);
    callback(null, doc);
  };
}